==> php54-owncloud-8.0.2.tgz: share/owncloud/settings/l10n/is.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "Villa við auðkenningu",
    "Language changed" : "Tungumáli breytt",
    "Invalid request" : "Ógild fyrirspurn",
    "Admins can't remove themself from the admin group" : "Stjórnendur geta ekki fjarlægt sjálfa sig úr stjórnendahóp",
    "Unable to add user to group %s" : "Ekki tókst að bæta notenda við hópinn %s",
    "Unable to remove user from group %s" : "Ekki tókst að fjarlægja notanda úr hópnum %s",
    "Email sent" : "Tölvupóstur sendur",
    "Email saved" : "Netfang vistað",
    "Please wait...." : "Andartak....",
    "Disable" : "Gera óvirkt",
    "Enable" : "Virkja",
    "Updating...." : "Uppfæri...",
    "Updated" : "Uppfært",
    "Delete" : "Eyða",
    "Groups" : "Hópar",
    "undo" : "afturkalla",
    "never" : "aldrei",
    "__language_name__" : "__nafn_tungumáls__",
    "SSL root certificates" : "SSL rótar skilríki",
    "Encryption" : "Dulkóðun",
    "None" : "Ekkert",
    "Security Warning" : "Öryggis aðvörun",
    "Server address" : "Host nafn netþjóns",
    "More" : "Meira",
    "Less" : "Minna",
    "Version" : "Útgáfa",
    "Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." : "Þróað af <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud samfélaginu</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">forrita kóðinn</a> er skráðu með <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
    "by" : "af",
    "User Documentation" : "Notenda handbók",
    "Administrator Documentation" : "Stjórnenda handbók",
    "Online Documentation" : "Handbók á netinu",
    "Forum" : "Vefspjall",
    "Bugtracker" : "Villubókhald",
    "Commercial Support" : "Borgaður stuðningur",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Þú hefur notað <strong>%s</strong> af tiltæku <strong>%s</strong>",
    "Password" : "Lykilorð",
    "Your password was changed" : "Lykilorði þínu hefur verið breytt",
    "Unable to change your password" : "Ekki tókst að breyta lykilorðinu þínu",
    "Current password" : "Núverandi lykilorð",
    "New password" : "Nýtt lykilorð",
    "Change password" : "Breyta lykilorði",
    "Email" : "Netfang",
    "Your email address" : "Netfangið þitt",
    "Cancel" : "Hætta við",
    "Language" : "Tungumál",
    "Help translate" : "Hjálpa við þýðingu",
    "Import Root Certificate" : "Flytja inn rótar skilríki",
    "Username" : "Notendanafn",
    "Create" : "Búa til",
    "Unlimited" : "Ótakmarkað",
    "Other" : "Annað",
    "Default" : "Sjálfgefið"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/settings/l10n/is.js <==
OC.L10N.register(
    "settings",
    {
    "External Storage" : "Ytri gagnageymsla",
    "Authentication error" : "Villa við auðkenningu",
    "Language changed" : "Tungumáli breytt",
    "Invalid request" : "Ógild fyrirspurn",
    "Admins can't remove themself from the admin group" : "Stjórnendur geta ekki fjarlægt sjálfa sig úr stjórnendahóp",
    "Unable to add user to group %s" : "Ekki tókst að bæta notenda við hópinn %s",
    "Unable to remove user from group %s" : "Ekki tókst að fjarlægja notanda úr hópnum %s",
    "Email sent" : "Tölvupóstur sendur",
    "Email saved" : "Netfang vistað",
    "Please wait...." : "Andartak....",
    "Disable" : "Gera óvirkt",
    "Enable" : "Virkja",
    "Updating...." : "Uppfæri...",
    "Updated" : "Uppfært",
    "Delete" : "Eyða",
    "Groups" : "Hópar",
    "undo" : "afturkalla",
    "never" : "aldrei",
    "__language_name__" : "__nafn_tungumáls__",
    "SSL root certificates" : "SSL rótar skilríki",
    "None" : "Ekkert",
    "Encryption" : "Dulkóðun",
    "Server address" : "Host nafn netþjóns",
    "More" : "Meira",
    "Less" : "Minna",
    "Version" : "Útgáfa",
    "by" : "af",
    "User Documentation" : "Notenda handbók",
    "Forum" : "Vefspjall",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Þú hefur notað <strong>%s</strong> af tiltæku <strong>%s</strong>",
    "Password" : "Lykilorð",
    "Unable to change your password" : "Ekki tókst að breyta lykilorðinu þínu",
    "Current password" : "Núverandi lykilorð",
    "New password" : "Nýtt lykilorð",
    "Change password" : "Breyta lykilorði",
    "Email" : "Netfang",
    "Your email address" : "Netfangið þitt",
    "Cancel" : "Hætta við",
    "Language" : "Tungumál",
    "Help translate" : "Hjálpa við þýðingu",
    "Username" : "Notendanafn",
    "Create" : "Búa til",
    "Unlimited" : "Ótakmarkað",
    "Other" : "Annað",
    "Default" : "Sjálfgefið"
},
"nplurals=2; plural=(n % 10 == 1 || n % 100 != 11);");
